@@ -67,6 +67,10 @@ API
 What's new
 ----------
 
+version 1.3.3:
+
+- fixed a bug in `resolve` which left "../" at the begining of some paths
+
 version 1.3.2:
 
 - convenience function `match`
@@ -93,7 +97,7 @@ version 1.2.1:
 .. _regex: http://pypi.python.org/pypi/regex
 
 """
-__version__ = '1.3.2'
+__version__ = '1.3.3'
 
 import sys
 
@@ -269,13 +273,13 @@ def format_patterns(**names):
     Patterns are `str` instances (be it in python 2.x or 3.x) containing ASCII
     characters only.
 
-    Caveats::
+    Caveats:
 
       - with re_, named capture groups cannot occur on multiple branches of an
         alternation
 
       - with re_ before python 3.3, ``\u`` and ``\U`` escapes must be
-        preprocessed (see `issue3665 <http://bugs.python.org/issue3665>`_)::
+        preprocessed (see `issue3665 <http://bugs.python.org/issue3665>`_)
 
       - on narrow builds, character ranges beyond BMP are not supported
 
@@ -468,6 +472,13 @@ def resolve(base, uriref, strict=True, return_parts=False):
     
     If `return_parts` is True, returns a dict of named parts instead of
     a string.
+
+    Examples::
+
+        >>> assert resolve('urn:rootless', '../../name') == 'urn:name'
+        >>> assert resolve('urn:root/less', '../../name') == 'urn:/name'
+        >>> assert resolve('http://a/b', 'http:g') == 'http:g'
+        >>> assert resolve('http://a/b', 'http:g', strict=False) == 'http://a/g'
         
     .. _Resolves: http://tools.ietf.org/html/rfc3986#section-5.2
 
@@ -486,7 +497,7 @@ def resolve(base, uriref, strict=True, return_parts=False):
         R = _i2u(dict(uriref))
     
     # _last_segment = get_compiled_pattern(r'(?<=^|/)%(segment)s$')
-    _dot_segments = get_compiled_pattern(r'^\.{1,2}(?:/|$)|(?<=/)\.(?:/|$)')
+    _dot_segments = get_compiled_pattern(r'^(?:\.{1,2}(?:/|$))+|(?<=/)\.(?:/|$)')
     _2dots_segments = get_compiled_pattern(r'/?%(segment)s/\.{2}(?:/|$)')
     
     if R['scheme'] and (strict or R['scheme'] != B['scheme']):
@@ -564,6 +575,10 @@ resolve.test_cases = {
     "g/../h"        :  "http://a/b/c/h",
     "g;x=1/./y"     :  "http://a/b/c/g;x=1/y",
     "g;x=1/../y"    :  "http://a/b/c/y",
+    "g?y/./x"       :  "http://a/b/c/g?y/./x",
+    "g?y/../x"      :  "http://a/b/c/g?y/../x",
+    "g#s/./x"       :  "http://a/b/c/g#s/./x",
+    "g#s/../x"      :  "http://a/b/c/g#s/../x",
     }
 
 
